@@ -7,6 +7,7 @@ import unittest
 sys.path.append(os.path.dirname(__file__))  # let code under test load stubs
 from context import Context
 from fake_snmp import FakeSnmpClient
+from fake_ssh import FakeSshClient
 from preseem import NetworkMetadataReference
 from preseem.ssl_probe import SslProbeResult
 from check import check
@@ -21,6 +22,7 @@ class TestCheck(unittest.TestCase):
     def setUp(self):
         self.ctx = Context('test', {}, None, {}, fake=True, job=True)
         self.ctx.ping = fake_ping
+        self.ctx.ssh_client_cls = FakeSshClient
         self.ctx.snmp_client_cls = FakeSnmpClient
         self.ctx.ssl_probe = fake_ssl_probe
         self.loop = asyncio.new_event_loop()
@@ -60,7 +62,7 @@ class TestCheck(unittest.TestCase):
             self.assertIn(csvfile, ('/tmp/preseem-aps.csv', '/tmp/preseem-routers.csv', '/tmp/preseem-switches.csv', '/tmp/preseem-olts.csv'))
             if csvfile == '/tmp/preseem-aps.csv':
                 self.assertEqual(len(rows), 1)
-                self.assertEqual(rows[0], ('ap01', 'Site 1', 'AP 1', '192.0.2.1', True, None, None, None, None, None, 'Tarana Wireless', 'S134F2215100421.radio.taranawireless.com'))
+                self.assertEqual(rows[0], ('ap01', 'Site 1', 'AP 1', '192.0.2.1', True, None, None, None, None, None, None, 'Tarana Wireless', 'S134F2215100421.radio.taranawireless.com'))
             elif csvfile == '/tmp/preseem-routers.csv':
                 self.assertEqual(len(rows), 0)
         self._await(check(self.ctx, check_output))
@@ -104,5 +106,5 @@ class TestCheck(unittest.TestCase):
                 self.assertEqual(rows[0], ('ap01', 'Site 1', 'AP 1', '192.0.2.1', True, None, None, None))
             elif csvfile == '/tmp/preseem-olts.csv':
                 self.assertEqual(len(rows), 1)
-                self.assertEqual(rows[0], ('olt01', 'OLT 1', '192.0.2.254', True, None, None, None, None))
+                self.assertEqual(rows[0], ('olt01', 'OLT 1', '192.0.2.254', True, None, None, None, None, None))
         self._await(check(self.ctx, check_output))
